package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.ISettingDictDataService;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.setting.DictDataCreateValidate;
import com.mdd.admin.validate.setting.DictDataUpdateValidate;
import com.mdd.admin.vo.setting.SettingDictDataVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.setting.DictData;
import com.mdd.common.entity.setting.DictType;
import com.mdd.common.mapper.setting.DictDataMapper;
import com.mdd.common.mapper.setting.DictTypeMapper;
import com.mdd.common.util.TimeUtils;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

@Service
public class SettingDictDataServiceImpl implements ISettingDictDataService {
   @Resource
   DictDataMapper dictDataMapper;
   @Resource
   DictTypeMapper dictTypeMapper;

   public List<SettingDictDataVo> all(Map<String, String> params) {
      DictType dictType = (DictType)this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("dict_type", params.get("dictType"))).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(dictType, "该字典类型不存在!", new Object[0]);
      QueryWrapper<DictData> queryWrapper = new QueryWrapper();
      queryWrapper.select(new String[]{"id,type_id,name,value,remark,sort,status,create_time,update_time"});
      queryWrapper.eq("is_delete", 0);
      queryWrapper.eq("type_id", dictType.getId());
      queryWrapper.orderByDesc("id");
      this.dictDataMapper.setSearch(queryWrapper, params, new String[]{"like:name:str", "like:value:str", "=:status:int"});
      List<DictData> dictDataList = this.dictDataMapper.selectList(queryWrapper);
      List<SettingDictDataVo> list = new LinkedList();
      Iterator var6 = dictDataList.iterator();

      while(var6.hasNext()) {
         DictData dictData = (DictData)var6.next();
         SettingDictDataVo vo = new SettingDictDataVo();
         BeanUtils.copyProperties(dictData, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(dictData.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(dictData.getUpdateTime()));
         list.add(vo);
      }

      return list;
   }

   public PageResult<SettingDictDataVo> list(PageValidate pageValidate, Map<String, String> params) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      DictType dictType = (DictType)this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("is_delete", 0)).eq("dict_type", params.get("dictType"))).last("limit 1"));
      Assert.notNull(dictType, "该字典类型不存在!", new Object[0]);
      QueryWrapper<DictData> queryWrapper = new QueryWrapper();
      queryWrapper.select(new String[]{"id,type_id,name,value,remark,sort,status,create_time,update_time"});
      queryWrapper.eq("type_id", dictType.getId());
      queryWrapper.eq("is_delete", 0);
      queryWrapper.orderByDesc("id");
      this.dictDataMapper.setSearch(queryWrapper, params, new String[]{"like:name:str", "like:value:str", "=:status:int"});
      IPage<DictData> iPage = this.dictDataMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<SettingDictDataVo> list = new LinkedList();
      Iterator var9 = iPage.getRecords().iterator();

      while(var9.hasNext()) {
         DictData dictData = (DictData)var9.next();
         SettingDictDataVo vo = new SettingDictDataVo();
         BeanUtils.copyProperties(dictData, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(dictData.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(dictData.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public SettingDictDataVo detail(Integer id) {
      DictData dictData = (DictData)this.dictDataMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,type_id,name,value,remark,sort,status,create_time,update_time"}).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(dictData, "字典数据不存在！", new Object[0]);
      SettingDictDataVo vo = new SettingDictDataVo();
      BeanUtils.copyProperties(dictData, vo);
      vo.setCreateTime(TimeUtils.timestampToDate(dictData.getCreateTime()));
      vo.setUpdateTime(TimeUtils.timestampToDate(dictData.getUpdateTime()));
      return vo;
   }

   public void add(DictDataCreateValidate createValidate) {
      Assert.isNull(this.dictDataMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id"}).eq("name", createValidate.getName())).eq("is_delete", 0)).last("limit 1")), "字典数据已存在！", new Object[0]);
      DictData model = new DictData();
      model.setTypeId(createValidate.getTypeId());
      model.setName(createValidate.getName());
      model.setValue(createValidate.getValue());
      model.setRemark(createValidate.getRemark());
      model.setSort(createValidate.getSort());
      model.setStatus(createValidate.getStatus());
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.dictDataMapper.insert(model);
   }

   public void edit(DictDataUpdateValidate updateValidate) {
      DictData model = (DictData)this.dictDataMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("id", updateValidate.getId())).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(model, "字典数据不存在！", new Object[0]);
      Assert.isNull(this.dictDataMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id"}).ne("id", updateValidate.getId())).eq("name", updateValidate.getName())).eq("is_delete", 0)).last("limit 1")), "字典数据已存在！", new Object[0]);
      model.setName(updateValidate.getName());
      model.setValue(updateValidate.getValue());
      model.setRemark(updateValidate.getRemark());
      model.setSort(updateValidate.getSort());
      model.setStatus(updateValidate.getStatus());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.dictDataMapper.updateById(model);
   }

   public void del(List<Integer> ids) {
      Iterator var2 = ids.iterator();

      while(var2.hasNext()) {
         Integer id = (Integer)var2.next();
         DictData model = new DictData();
         model.setId(id);
         model.setIsDelete(1);
         model.setDeleteTime(System.currentTimeMillis() / 1000L);
         this.dictDataMapper.updateById(model);
      }

   }
}
